% --------------------------------------------------------------------------
% the SUBSTANCES package
% 
%   A Chemical Database
% 
% --------------------------------------------------------------------------
% Clemens Niederberger
% Web:    https://bitbucket.org/cgnieder/substances/
% E-Mail: contact@mychemistry.eu
% --------------------------------------------------------------------------
% Copyright 2012 Clemens Niederberger
% 
% This work may be distributed and/or modified under the
% conditions of the LaTeX Project Public License, either version 1.3
% of this license or (at your option) any later version.
% The latest version of this license is in
%   http://www.latex-project.org/lppl.txt
% and version 1.3 or later is part of all distributions of LaTeX
% version 2005/12/01 or later.
% 
% This work has the LPPL maintenance status `maintained'.
% 
% The Current Maintainer of this work is Clemens Niederberger.
% --------------------------------------------------------------------------
% The substances package consists of the files
%  - substances.sty, substances-default.def, substances-examples.sub,
%    substances_en.tex, substances_en.pdf, README
% --------------------------------------------------------------------------
% If you have any ideas, questions, suggestions or bugs to report, please
% feel free to contact me.
% --------------------------------------------------------------------------
% substances: default style
\RequirePackage { chemfig , siunitx }

% ----------------------------------------------------------------------------
% helper functions for the GHS properties:
\cs_new:Npn \substances_get_pics:n #1
  {
    \int_zero:N \l_tmpa_int
    \clist_map_inline:nn { #1 }
      {
        \int_incr:N \l_tmpa_int
        \int_compare:nF { \l_tmpa_int = 1 } { ~ }
        \ghspic{##1}
      }
  }

\cs_new:Npn \substances_get_ghs:nn #1#2
  {
    \int_zero:N \l_tmpa_int
    \clist_map_inline:nn { #2 }
      {
        \int_incr:N \l_tmpa_int
        \int_compare:nF { \l_tmpa_int = 1 }
          { \bool_if:NT \l_ghsystem_hide_statement_bool { , } ~ }
        \ghs{#1}{##1}
      }
  }

% ----------------------------------------------------------------------------
\DeclareSubstanceProperty  { formula }    [\ch]
\DeclareSubstanceProperty  { structure }  [\chemfig]
\DeclareSubstanceProperty  { mass }       [\SI][{\MolMass}]
\DeclareSubstanceProperty  { bp }         [\SI][{\celsius}]
\DeclareSubstanceProperty  { mp }         [\SI][{\celsius}]
\DeclareSubstanceProperty  { density }    [\SI][{\gram\per\cmc}]
\DeclareSubstanceProperty  { phase }
\DeclareSubstanceProperty  {pKa}          [\num]
\DeclareSubstanceProperty  {pKa1}         [\num]
\DeclareSubstanceProperty  {pKa2}         [\num]
\DeclareSubstanceProperty  {pKb}          [\num]
\DeclareSubstanceProperty  {pKb1}         [\num]
\DeclareSubstanceProperty  {pKb2}         [\num]
\DeclareSubstanceProperty  { pictograms } [\substances_get_pics:n]
\DeclareSubstanceProperty  { H }          [\substances_get_ghs:nn{H}]
\DeclareSubstanceProperty  { P }          [\substances_get_ghs:nn{P}]
\DeclareSubstanceProperty  { EUH }        [\substances_get_ghs:nn{EUH}]
\DeclareSubstanceProperty  {LD50}         [\SI][{\milli\gram\per\kilo\gram}]

\tex_endinput:D